import React from "react"

import { Button, Card, Carousel } from "@onegeo/gatsby-theme-onegeo"

interface Service {
    name: string
    description: string
    image: string
    url: string
}
interface Action {
    name: string
    url: string
}
interface Bg {
    src: string
}
interface Props {
    title?: string
    subtitle?: string
    content?: string
    action?: Action
    services?: Array<Service>
    bgImage?: Array<Bg>
    size?: "xs" | "base" | "xl"
}

const Hero = (props: Props) => {
    // Data structure (default value)
    const {
        title = "eGEO Project",
        subtitle = "Hub géospatial collaboratif",
        content = "Solution Open Source sur-mesure pour communiquer et valoriser les données disponibles sur votre territoire ou vos infrastructures.",
        action = {
            name: "Découvres nos cartes interactives",
            url: "#",
        },
        services = [
            {
                name: "Datastore",
                description: "Accédez à votre catalogue de données.",
                image: "../images/hero/datastore.png",
                url: "#",
            },
            {
                name: "Map",
                description:
                    "Consulter, gérer, mettre à jour et diffuser vos contenus cartographiques.",
                image: "../images/hero/datastore.png",
                url: "#",
            },
            {
                name: "Dataviz",
                description: "Croisez et mettez en forme vos données.",
                image: "../images/hero/datastore.png",
                url: "#",
            },
            {
                name: "Contrib",
                description: "Validez et collectez vos informations.",
                image: "../images/hero/datastore.png",
                url: "#",
            },
        ],
        bgImage = [
            {
                src: "https://images.unsplash.com/photo-1608501078713-8e445a709b39?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mnx8d2FsbHBhcGVyJTIwNGt8ZW58MHx8MHx8&w=1000&q=80",
            },
            {
                src: "https://images.unsplash.com/photo-1608501078713-8e445a709b39?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mnx8d2FsbHBhcGVyJTIwNGt8ZW58MHx8MHx8&w=1000&q=80",
            },
            {
                src: "https://images.unsplash.com/photo-1608501078713-8e445a709b39?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxzZWFyY2h8Mnx8d2FsbHBhcGVyJTIwNGt8ZW58MHx8MHx8&w=1000&q=80",
            },
        ],
        size = "base",
    } = props

    let imageFondList, imageFond

    if (bgImage.length > 1) {
        imageFondList = bgImage
        imageFond = [
            imageFondList.map((image: any) => {
                return image
            }),
        ]
    } else {
        imageFond = bgImage![0]
    }

    return (
        <div
            className={`relative z-0 ${
                size == "base" ? "mb-28 h-[60vh]" : ""
            } ${size == "xl" ? "h-[75vh]" : ""} ${
                size == "xs" ? "mb-56 h-[50vh]" : ""
            } bg-cover`}
            style={{ backgroundImage: `url(${imageFond})` }}
        >
            {bgImage!.length > 1 && (
                <Carousel
                    height={`${size == "base" ? "h-[60vh]" : ""} ${
                        size == "xl" ? "h-[75vh]" : ""
                    } ${size == "xs" ? "h-[50vh]" : ""}`}
                    images={imageFond[0]}
                    animation="fade"
                    delay={3000}
                />
            )}
            <div
                className={`text-neutral-content absolute top-2 left-1/2 z-10 mb-5 -translate-x-1/2 text-center`}
            >
                <div className="max-w-4xl">
                    <h1 className="mb-5 text-3xl font-extrabold tracking-tight lg:text-6xl">
                        {title}
                        <div className="text-primary">{subtitle}</div>
                    </h1>
                    <p className="mb-5">{content}</p>
                    {action ? (
                        <Button
                            className="btn-primary text-white"
                            {...action}
                        />
                    ) : null}
                </div>
            </div>
            <div
                className={`absolute ${size == "base" ? "-bottom-28" : ""} ${
                    size == "xl" ? "bottom-6" : ""
                } ${
                    size == "xs" ? "-bottom-52" : ""
                } left-1/2 z-10 mx-6 mt-5 flex -translate-x-1/2 flex-col gap-6 lg:flex-row`}
            >
                {services &&
                    services.map((service, idx) => (
                        <Card key={idx} {...service} />
                    ))}
            </div>
            <div className="row-start-3">&nbsp;</div>
        </div>
    )
}

export default Hero
