import React from "react"
import Image, { Iimage } from "./Image"
import { Link } from "@onegeo/gatsby-theme-onegeo"
import cx from "classix"

interface IStyle {
    main: string
    description: string
    image: string
}

interface IOptions {
    style: object
}
export interface ICard extends Iimage {
    children?: React.ReactNode
    name?: string
    description?: string
    url?: string
    anime?: boolean
    layout?: "top" | "left" | "full"
    size?: "xs" | "base" | "xl"
    style?: IStyle
    options?: IOptions
}

const oClass = {
    full_base: {
        main: "image-full ",
        title: "",
        description: "",
        image: "h-52",
    },
    top_base: {
        main: "",
        title: "",
        description: "h-24",
        image: "h-52",
    },
    top_xs: {
        main: "",
        title: "",
        description: "h-12",
        image: "h-28",
    },
    top_xl: {
        main: "",
        title: "",
        description: "h-32",
        image: "h-72",
    },
    left_base: {
        main: "card-side h-52 w-full ",
        title: "",
        description: "",
        image: "min-w-[320px] max-w-[320px]",
    },
    left_xs: {
        main: "card-side h-28 w-full ",
        title: "",
        description: "line-clamp-2",
        image: "min-w-[80px] max-w-[100px]",
    },
    left_xl: {
        main: "card-side h-72 w-full ",
        title: "",
        description: "line-clamp-2",
        image: "min-w-[450px] max-w-[450px]",
    },
}

const CardContent = (props: ICard) => {
    const {
        children,
        layout = "top",
        name,
        description,
        image,
        size = "base",
        style,
        options = {
            style: {},
        },
    } = props

    const oclass = style || oClass[layout + "_" + size] || oClass["top_base"]

    return (
        <>
            {image ? (
                <div className={cx(oclass.image, options.style.image)}>
                    <Image
                        image={image}
                        className="h-full w-full object-cover"
                    />
                </div>
            ) : null}
            <div className={cx("card-body", options.style.body)}>
                {name ? (
                    <h2
                        className={cx(
                            "card-title uppercase",
                            oclass.title,
                            options.style.title
                        )}
                    >
                        {name}
                    </h2>
                ) : null}
                {description ? (
                    <div
                        className={
                            "overflow-hidden text-ellipsis text-justify " +
                            oclass.description
                        }
                        dangerouslySetInnerHTML={{ __html: description }}
                    />
                ) : null}
                {children}
            </div>
        </>
    )
}

const Card = (props: ICard) => {
    const {
        className = "",
        anime = true,
        layout = "top",
        size = "base",
        style,
        url,
        options = {
            style: {},
        },
    } = props

    const transition = anime
        ? "lg:transition duration-200 ease-in-out lg:hover:-translate-y-2 lg:hover:shadow-xl "
        : ""

    const oclass = style || oClass[layout + "_" + size] || oClass["top_base"]

    return url ? (
        <Link
            to={url}
            className={cx(
                "card card-compact bg-base-100 text-base-content shadow-lg",
                oclass.main,
                transition,
                className,
                options.style.main
            )}
        >
            <CardContent {...props} />
        </Link>
    ) : (
        <div
            className={cx(
                "card card-compact bg-base-100 text-base-content shadow-lg",
                oclass.main,
                transition,
                className,
                options.style.main
            )}
        >
            <CardContent {...props} />
        </div>
    )
}

export default Card
