import React from "react"
import Card, { ICard } from "./Card"

interface Props {
    cards?: ICard[]
    layout?: "row" | "col" | "grid"
    className?: string
}

const oCardProps = {
    row: {
        layout: "left",
        className: "",
    },
    col: {
        layout: "top",
        className: "",
    },
    grid: {
        layout: "top",
        className: "max-w-full",
    },
}

const CardList = (props: Props) => {
    const { cards = [], layout = "row", className = "" } = props

    const oListClassName = {
        row: `space-y-10 w-full ${className}`,
        col: `flex space-x-12 flex-nowrap justify-center ${className}`,
        grid: `grid grid-cols-1 md:grid-cols-2 xl:grid-cols-3 gap-12 ${className}`,
    }

    const tmpProps = oCardProps[layout]

    const listCards = cards.map((card, index) => {
        let cardProps = {
            ...card,
            ...tmpProps,
        }

        return <Card key={index} {...(cardProps as ICard)} />
    })

    return <div className={oListClassName[layout]}>{listCards}</div>
}

export default CardList
